@@ -8,6 +8,9 @@ from django.dispatch import receiver
 from djangoldp.models import Model
 from .permissions import CirclePermissions, CircleMemberPermissions
 from .views import CircleMembersViewset
+import logging
+
+logger = logging.getLogger('djangoldp')
 
 
 MODEL_MODIFICATION_USER_FIELD = 'modification_user'
@@ -79,11 +82,12 @@ def fix_user_hubl_workaround_493(sender, instance, **kwargs):
         try:
             request_user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, None)
             if request_user is None:
-                raise Exception()
+                raise Exception('request user was unexpectedly None!')
             user = get_user_model().objects.get(pk=request_user.pk)
             instance.user = user
             instance.save()
-        except:
+        except Exception as e:
+            logger.error('error in Circle.fix_user_hubl_workaround_493.. ' + str(e))
             if instance.pk is not None:
                 instance.delete()
 
